@@ -1,9 +1,10 @@
-from typing import List, Tuple
+from typing import List
+from typing import Tuple
 
 import pandas as pd
 
 
-class DatasetReader(object):
+class DatasetReader:
     def read_source_data(self) -> List[Tuple[str, pd.DataFrame]]:
         raise NotImplementedError("This method is not implemented.")
 
